# learn_rec_algorithm
学习和验证推荐算法

# 环境准备
## Python环境准备
```
virtualenv .venv --python=python3.7
source ./venv/bin/activate
pip install deepctr
pip install tensorflow==1.15
pip install tqdm
```

# 上传制品
```
pip install twine
python setup.py sdist
twine upload dist/*
```